
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.40'
version = '1.2.40'
full_version = '1.2.40'
git_revision = 'ec71fd5c33f6293612b18e779b6b2a216bae5123'
release = True

if not release:
    version = full_version
    short_version += ".dev"
